==> Paws-0.38.tar.gz: Paws-0.38/lib/Paws/RDS/DeleteOptionGroup.pm <==

package Paws::RDS::DeleteOptionGroup;
  use Moose;
  has OptionGroupName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteOptionGroup');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::RDS::DeleteOptionGroup - Arguments for method DeleteOptionGroup on L<Paws::RDS>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteOptionGroup on the
L<Amazon Relational Database Service|Paws::RDS> service. Use the attributes of this class
as arguments to method DeleteOptionGroup.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteOptionGroup.

=head1 SYNOPSIS

    my $rds = Paws->service('RDS');
    # To delete an option group.
    # This example deletes the specified option group.
    $rds->DeleteOptionGroup(
      {
        'OptionGroupName' => 'mydboptiongroup'
      }
    );


Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/rds/DeleteOptionGroup>

=head1 ATTRIBUTES


=head2 B<REQUIRED> OptionGroupName => Str

The name of the option group to be deleted.

You can't delete default option groups.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteOptionGroup in L<Paws::RDS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut

==> Paws-0.42.tar.gz: Paws-0.42/lib/Paws/RDS/DeleteOptionGroup.pm <==

package Paws::RDS::DeleteOptionGroup;
  use Moose;
  has OptionGroupName => (is => 'ro', isa => 'Str', required => 1);

  use MooseX::ClassAttribute;

  class_has _api_call => (isa => 'Str', is => 'ro', default => 'DeleteOptionGroup');
  class_has _returns => (isa => 'Str', is => 'ro', default => 'Paws::API::Response');
  class_has _result_key => (isa => 'Str', is => 'ro');
1;

### main pod documentation begin ###

=head1 NAME

Paws::RDS::DeleteOptionGroup - Arguments for method DeleteOptionGroup on L<Paws::RDS>

=head1 DESCRIPTION

This class represents the parameters used for calling the method DeleteOptionGroup on the
L<Amazon Relational Database Service|Paws::RDS> service. Use the attributes of this class
as arguments to method DeleteOptionGroup.

You shouldn't make instances of this class. Each attribute should be used as a named argument in the call to DeleteOptionGroup.

=head1 SYNOPSIS

    my $rds = Paws->service('RDS');
    # To delete an option group.
    # This example deletes the specified option group.
    $rds->DeleteOptionGroup( 'OptionGroupName' => 'mydboptiongroup' );


Values for attributes that are native types (Int, String, Float, etc) can passed as-is (scalar values). Values for complex Types (objects) can be passed as a HashRef. The keys and values of the hashref will be used to instance the underlying object.
For the AWS API documentation, see L<https://docs.aws.amazon.com/goto/WebAPI/rds/DeleteOptionGroup>

=head1 ATTRIBUTES


=head2 B<REQUIRED> OptionGroupName => Str

The name of the option group to be deleted.

You can't delete default option groups.




=head1 SEE ALSO

This class forms part of L<Paws>, documenting arguments for method DeleteOptionGroup in L<Paws::RDS>

=head1 BUGS and CONTRIBUTIONS

The source code is located here: L<https://github.com/pplu/aws-sdk-perl>

Please report bugs to: L<https://github.com/pplu/aws-sdk-perl/issues>

=cut
